@@ -19,62 +19,65 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # internationalization
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.sgettext
 from ..views.treemodels import EventModel
 from .baseselector import BaseSelector
-from gramps.gui.display import display_help
 from gramps.gen.const import URL_MANUAL_SECT1
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Constants
 #
-#-------------------------------------------------------------------------
-WIKI_HELP_PAGE = URL_MANUAL_SECT1
-WIKI_HELP_SEC = _('manual|Select_Event_selector')
+# -------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # SelectEvent
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class SelectEvent(BaseSelector):
-
     def _local_init(self):
         """
         Perform local initialisation for this class
         """
-        self.width_key = 'interface.event-sel-width'
-        self.height_key = 'interface.event-sel-height'
+        self.setup_configs("interface.event-sel", 600, 450)
 
     def get_window_title(self):
         return _("Select Event")
-        
+
     def get_model_class(self):
         return EventModel
 
     def get_column_titles(self):
         return [
-            (_('Type'),              100, BaseSelector.TEXT, 2),
-            (_('Main Participants'), 250, BaseSelector.TEXT, 8),
-            (_('Date'),              150, BaseSelector.TEXT, 3),
-            (_('Place'),             250, BaseSelector.TEXT, 4),
-            (_('Description'),       150, BaseSelector.TEXT, 0),
-            (_('ID'),                75,  BaseSelector.TEXT, 1),
-            (_('Last Change'),       150, BaseSelector.TEXT, 7)
-            ]
+            (_("Type"), 100, BaseSelector.TEXT, 2),
+            (_("Main Participants"), 250, BaseSelector.TEXT, 8),
+            (_("Date"), 150, BaseSelector.TEXT, 3),
+            (_("Place"), 250, BaseSelector.TEXT, 4),
+            (_("Description"), 150, BaseSelector.TEXT, 0),
+            (_("ID"), 75, BaseSelector.TEXT, 1),
+            (_("Last Change"), 150, BaseSelector.TEXT, 7),
+        ]
 
     def get_from_handle_func(self):
         return self.db.get_event_from_handle
+
+    def get_config_name(self):
+        return __name__
+
+    WIKI_HELP_PAGE = URL_MANUAL_SECT1
+    WIKI_HELP_SEC = _("Select_Event_selector", "manual")
