@@ -25,38 +25,26 @@
 ## Found by redwood:
 ## http://www.gramps-project.org/bugs/view.php?id=2611
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# Python modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
-import gi
-gi.require_version('Gtk', '3.0')
-from gi.repository import Pango
-from gi.repository import Gtk
-import math
-from gi.repository import Gdk
-try:
-    import cairo
-except ImportError:
-    pass
-
-#-------------------------------------------------------------------------
-#
-# GRAMPS modules
-#
-#-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
+# -------------------------------------------------------------------------
 from gramps.gen.plug import Gramplet
-from gramps.gen.errors import WindowActiveError
-from gramps.gui.editors import EditPerson
-from gramps.gui.widgets.fanchart import (FanChartWidget, FanChartGrampsGUI,
-                    FORM_HALFCIRCLE, BACKGROUND_SCHEME1)
+from gramps.gui.widgets.fanchart import (
+    FanChartWidget,
+    FanChartGrampsGUI,
+    FORM_HALFCIRCLE,
+    BACKGROUND_SCHEME1,
+)
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+
+_ = glocale.translation.gettext
+
 
 class FanChartGramplet(FanChartGrampsGUI, Gramplet):
     """
-    The Gramplet code that realizes the FanChartWidget. 
+    The Gramplet code that realizes the FanChartWidget.
     """
 
     def __init__(self, gui, nav_group=0):
@@ -65,22 +53,30 @@ class FanChartGramplet(FanChartGrampsGUI, Gramplet):
         self.maxgen = 6
         self.background = BACKGROUND_SCHEME1
         self.childring = True
+        self.flipupsidedownname = True
+        self.twolinename = True
         self.radialtext = True
-        self.fonttype = 'Sans'
-        self.grad_start = '#0000FF'
-        self.grad_end = '#FF0000'
+        self.fonttype = "Sans"
+        self.grad_start = "#0000FF"
+        self.grad_end = "#FF0000"
         self.generic_filter = None
         self.alpha_filter = 0.2
         self.form = FORM_HALFCIRCLE
+        self.showid = False
         self.set_fan(FanChartWidget(self.dbstate, self.uistate, self.on_popup))
         # Replace the standard textview with the fan chart widget:
         self.gui.get_container_widget().remove(self.gui.textview)
-        self.gui.get_container_widget().add_with_viewport(self.fan)
+        self.gui.get_container_widget().add(self.fan)
         # Make sure it is visible:
         self.fan.show()
 
     def init(self):
-        self.set_tooltip(_("Click to expand/contract person\nRight-click for options\nClick and drag in open area to rotate"))
+        self.set_tooltip(
+            _(
+                "Click to expand/contract person\nRight-click for "
+                "options\nClick and drag in open area to rotate"
+            )
+        )
 
     def active_changed(self, handle):
         """
@@ -91,6 +87,7 @@ class FanChartGramplet(FanChartGrampsGUI, Gramplet):
 
     def on_childmenu_changed(self, obj, person_handle):
         """Callback for the pulldown menu selection, changing to the person
-           attached with menu item."""
-        self.set_active('Person', person_handle)
+        attached with menu item."""
+        dummy_obj = obj
+        self.set_active("Person", person_handle)
         return True
