@@ -21,36 +21,39 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# $Id: categorysidebar.py 20634 2012-11-07 17:53:14Z bmcage $
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # GNOME modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gtk
+from gi.repository import Gio
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.config import config
 from gramps.gui.basesidebar import BaseSidebar
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
-#-------------------------------------------------------------------------
+
+
+# -------------------------------------------------------------------------
 #
 # DropdownSidebar class
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class DropdownSidebar(BaseSidebar):
     """
-    A sidebar displaying toggle buttons and buttons with drop-down menus that 
+    A sidebar displaying toggle buttons and buttons with drop-down menus that
     allows the user to change the current view.
     """
-    def __init__(self, dbstate, uistate, categories, views):
 
+    def __init__(self, dbstate, uistate, categories, views):
         self.viewmanager = uistate.viewmanager
         self.views = views
 
@@ -62,13 +65,22 @@ class DropdownSidebar(BaseSidebar):
         self.window.add(grid)
         self.window.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
         self.window.show()
-        
-        use_text = config.get('interface.sidebar-text')
+
+        use_text = config.get("interface.sidebar-text")
         for cat_num, cat_name, cat_icon in categories:
             self.__make_category(grid, use_text, cat_num, cat_name, cat_icon)
 
         grid.show_all()
 
+        action_group = Gio.SimpleActionGroup()
+        action_group.add_action_entries(
+            [
+                ("select", self.__menu_selected, "(ii)"),
+            ],
+            None,
+        )
+        self.window.insert_action_group("sidebar", action_group)
+
     def get_top(self):
         """
         Return the top container widget for the GUI.
@@ -87,27 +99,20 @@ class DropdownSidebar(BaseSidebar):
             else:
                 button.set_active(False)
         self.__handlers_unblock()
-        
+
     def __handlers_block(self):
         """
         Block signals to the buttons to prevent spurious events.
         """
-        for idx in range(len(self.buttons)):
-            self.buttons[idx].handler_block(self.button_handlers[idx])
-        
+        for idx, button in enumerate(self.buttons):
+            button.handler_block(self.button_handlers[idx])
+
     def __handlers_unblock(self):
         """
         Unblock signals to the buttons.
         """
-        for idx in range(len(self.buttons)):
-            self.buttons[idx].handler_unblock(self.button_handlers[idx])
-
-    def cb_view_clicked(self, radioaction, current, cat_num):
-        """
-        Called when a button causes a view change.
-        """
-        view_num = radioaction.get_current_value()
-        self.viewmanager.goto_page(cat_num, view_num)
+        for idx, button in enumerate(self.buttons):
+            button.handler_unblock(self.button_handlers[idx])
 
     def __category_clicked(self, button, cat_num):
         """
@@ -118,25 +123,25 @@ class DropdownSidebar(BaseSidebar):
         button.set_active(True)
         self.viewmanager.goto_page(cat_num, None)
 
-    def __view_clicked(self, button, cat_num):
+    def __make_menu(self, cat_num):
         """
         Called when a view drop-down arrow is clicked.
         """
-        self.menu = Gtk.Menu()
-        for item in self.views[cat_num]:
-            menuitem = Gtk.ImageMenuItem(label=item[1])
-            image = Gtk.Image.new_from_icon_name(item[2], Gtk.IconSize.MENU)
-            image.show()
-            menuitem.set_image(image)
-            menuitem.connect("activate", self.cb_menu_clicked, cat_num, item[0])
-            menuitem.show()
-            self.menu.append(menuitem)
-        self.menu.popup(None, None, cb_menu_position, button, 0, 0)
+        menu = Gio.Menu()
+        for view_num, label, icon in self.views[cat_num]:
+            menuitem = Gio.MenuItem.new(
+                label=label, detailed_action=f"sidebar.select(({cat_num}, {view_num}))"
+            )
+            menuitem.set_icon(Gio.ThemedIcon.new(iconname=icon))
+            menu.append_item(menuitem)
+        return menu
 
-    def cb_menu_clicked(self, menuitem, cat_num, view_num):
+    def __menu_selected(self, action, parameter, data):
         """
         Called when a view is selected from a drop-down menu.
         """
+        cat_num = parameter.get_child_value(0).get_int32()
+        view_num = parameter.get_child_value(1).get_int32()
         self.viewmanager.goto_page(cat_num, view_num)
 
     def __make_category(self, grid, use_text, cat_num, cat_name, cat_icon):
@@ -150,24 +155,23 @@ class DropdownSidebar(BaseSidebar):
 
         # create the drop-down button to display views
         if len(self.views[cat_num]) > 1:
-            dropdown = Gtk.Button()
+            dropdown = Gtk.MenuButton(use_popover=False)
             dropdown.set_relief(Gtk.ReliefStyle.NONE)
-            arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.DOWN, 
-                                        shadow_type=Gtk.ShadowType.NONE)
-            dropdown.add(arrow)
-            dropdown.connect('clicked', self.__view_clicked, cat_num)
-            dropdown.set_tooltip_text(_('Click to select a view'))
+            dropdown.set_tooltip_text(_("Click to select a view"))
+            menu = self.__make_menu(cat_num)
+            dropdown.set_menu_model(menu)
             grid.attach(dropdown, 1, cat_num, 1, 1)
+            dropdown.set_align_widget(grid)
 
         # add the tooltip
         button.set_tooltip_text(cat_name)
 
         # connect the signal, along with the cat_num as user data
-        handler_id = button.connect('clicked', self.__category_clicked, cat_num)
+        handler_id = button.connect("clicked", self.__category_clicked, cat_num)
         self.button_handlers.append(handler_id)
         button.show()
 
-        # add the image. If we are using text, use the BUTTON (larger) size. 
+        # add the image. If we are using text, use the BUTTON (larger) size.
         # otherwise, use the smaller size
         hbox = Gtk.Box()
         hbox.show()
@@ -187,12 +191,12 @@ class DropdownSidebar(BaseSidebar):
             hbox.pack_start(label, False, True, 0)
 
         button.add(hbox)
-            
+
         # Enable view switching during DnD
         button.drag_dest_set(0, [], 0)
-        button.connect('drag_motion', self.cb_switch_page_on_dnd, cat_num)
+        button.connect("drag_motion", self.cb_switch_page_on_dnd, cat_num)
 
-        grid.attach(button, 0, cat_num, 1, 1)        
+        grid.attach(button, 0, cat_num, 1, 1)
 
     def cb_switch_page_on_dnd(self, widget, context, xpos, ypos, time, page_no):
         """
@@ -202,21 +206,3 @@ class DropdownSidebar(BaseSidebar):
         if self.viewmanager.notebook.get_current_page() != page_no:
             self.viewmanager.notebook.set_current_page(page_no)
         self.__handlers_unblock()
-
-def cb_menu_position(*args):
-    """
-    Determine the position of the popup menu.
-    """
-    # takes two argument: menu, button
-    if len(args) == 2:
-        menu = args[0]
-        button = args[1]
-    # broken introspection can't handle MenuPositionFunc annotations corectly
-    else:
-        menu = args[0]
-        button = args[3]
-    ret_val, x_pos, y_pos = button.get_window().get_origin()
-    x_pos += button.get_allocation().x
-    y_pos += button.get_allocation().y + button.get_allocation().height
-    
-    return (x_pos, y_pos, False)
