@@ -19,7 +19,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-""" Unittest for testing POTFILES.in and Makefile contents """
+"""Unittest for testing POTFILES.in and Makefile contents"""
 
 # PYTHONPATH=/../gramps python po_test.py
 
@@ -27,8 +27,10 @@ import unittest
 import os
 import glob
 from test import test_util
+
 test_util.path_append_parent()
 
+
 def get_potfile(filename):
     with open(filename, "r") as fp:
         retvals = []
@@ -37,13 +39,16 @@ def get_potfile(filename):
                 retvals.append(line.strip())
     return retvals
 
+
 # POTFILES.skip
 
 excluded_files = get_potfile("../POTFILES.skip")
 
+
 class TestPOT(unittest.TestCase):
     potfiles = get_potfile("../POTFILES.in")
     count = 1
+
     def __init__(self, method_name, dir, file, searches):
         method_name = method_name % self.count
         TestPOT.count += 1
@@ -51,7 +56,7 @@ class TestPOT(unittest.TestCase):
         unittest.TestCase.__init__(self, method_name)
 
     def helper(self, dir, file, searches):
-        realpath = (dir + "/" + file)
+        realpath = dir + "/" + file
         pathfile = realpath[3:]
         if os.path.exists(realpath):
             with open(realpath, "r") as fp:
@@ -61,17 +66,20 @@ class TestPOT(unittest.TestCase):
                 if search in lines:
                     found = True
             if found:
-                self.assertFalse(pathfile[3:] not in excluded_files and
-                                 pathfile[3:] not in self.potfiles,
-                                 "'%s' is not in POTFILES.in" % (pathfile[3:],))
+                self.assertFalse(
+                    pathfile[3:] not in excluded_files
+                    and pathfile[3:] not in self.potfiles,
+                    "'%s' is not in POTFILES.in" % (pathfile[3:],),
+                )
             else:
-                self.assertTrue(True, "'%s' doesn't contain '%s'" %
-                                (file, search))
+                self.assertTrue(True, "'%s' doesn't contain '%s'" % (file, search))
         else:
             self.assertTrue(True, "'%s' doesn't exist" % file)
 
+
 class TestMake(unittest.TestCase):
     count = 1
+
     def __init__(self, method_name, dir, file):
         method_name = method_name % self.count
         TestMake.count += 1
@@ -79,7 +87,7 @@ class TestMake(unittest.TestCase):
         unittest.TestCase.__init__(self, method_name)
 
     def helper(self, dir, file):
-        realpath = (dir + "/" + file)
+        realpath = dir + "/" + file
         pathfile = realpath[3:]
         path, filename = realpath.rsplit("/", 1)
         makefile = path + "/Makefile.in"
@@ -88,13 +96,16 @@ class TestMake(unittest.TestCase):
         elif os.path.exists(makefile):
             with open(makefile, "r") as fp:
                 lines = fp.read()
-            self.assertTrue(filename in lines, "'%s' not in %s/Makefile.in" %
-                            (filename, path))
+            self.assertTrue(
+                filename in lines, "'%s' not in %s/Makefile.in" % (filename, path)
+            )
         else:
             self.assertTrue(True, "no makefile in '%s'" % dir)
 
+
 class TestGetText(unittest.TestCase):
     count = 1
+
     def __init__(self, method_name, pofile, searches):
         method_name = method_name % self.count
         TestGetText.count += 1
@@ -109,12 +120,16 @@ class TestGetText(unittest.TestCase):
         found = False
         for search in searches:
             found = (search in lines) or found
-        self.assertTrue(found, "'%s' is in POTFILES.in but does not contain '%s'" %
-                        (pofile, searches))
+        self.assertTrue(
+            found,
+            "'%s' is in POTFILES.in but does not contain '%s'" % (pofile, searches),
+        )
+
 
 class TestDups(unittest.TestCase):
     potfiles = get_potfile("../POTFILES.in")
     count = 1
+
     def __init__(self, method_name, potfile):
         method_name = method_name % self.count
         TestPOT.count += 1
@@ -122,8 +137,11 @@ class TestDups(unittest.TestCase):
         unittest.TestCase.__init__(self, method_name)
 
     def helper(self, potfile):
-        self.assertTrue(self.potfiles.count(potfile) == 1,
-                        "'%s' is in POTFILE.in more than once." % potfile)
+        self.assertTrue(
+            self.potfiles.count(potfile) == 1,
+            "'%s' is in POTFILE.in more than once." % potfile,
+        )
+
 
 def suite1():
     """
@@ -131,21 +149,28 @@ def suite1():
     is in a file, then that file better be in POTFILES.in.
     """
     suite = unittest.TestSuite()
-    for dir, subdir, files in os.walk('../../src'):
+    for dir, subdir, files in os.walk("../../src"):
         for file in files:
-            if glob.fnmatch.fnmatch(file,"*.py"):
-                suite.addTest(TestPOT('test_pot_py_%04d',
-                                      dir, file, ["import gettext",
-                                                  "import sgettext"]))
-            elif glob.fnmatch.fnmatch(file,"*.glade"):
-                suite.addTest(TestPOT('test_pot_glade_%04d',
-                                      dir, file, ["translatable=\"yes\""]))
-            if glob.fnmatch.fnmatch(file,"*.py"):
-                suite.addTest(TestMake('test_make_py_%04d', dir, file))
-            elif glob.fnmatch.fnmatch(file,"*.glade"):
-                suite.addTest(TestMake('test_make_glade_%04d', dir, file))
+            if glob.fnmatch.fnmatch(file, "*.py"):
+                suite.addTest(
+                    TestPOT(
+                        "test_pot_py_%04d",
+                        dir,
+                        file,
+                        ["import gettext", "import sgettext"],
+                    )
+                )
+            elif glob.fnmatch.fnmatch(file, "*.glade"):
+                suite.addTest(
+                    TestPOT("test_pot_glade_%04d", dir, file, ['translatable="yes"'])
+                )
+            if glob.fnmatch.fnmatch(file, "*.py"):
+                suite.addTest(TestMake("test_make_py_%04d", dir, file))
+            elif glob.fnmatch.fnmatch(file, "*.glade"):
+                suite.addTest(TestMake("test_make_glade_%04d", dir, file))
     return suite
 
+
 def suite2():
     """
     Suite of tests that check for each file in POTFILES.in, then it
@@ -155,21 +180,26 @@ def suite2():
     potfiles = get_potfile("../POTFILES.in")
     for potfile in potfiles:
         # do not call gettext
-        if glob.fnmatch.fnmatch(potfile,"*.gpr.py"):
+        if glob.fnmatch.fnmatch(potfile, "*.gpr.py"):
             continue
         # special case
-        if glob.fnmatch.fnmatch(potfile,"src/plugins/lib/libnarrate.py"):
+        if glob.fnmatch.fnmatch(potfile, "src/plugins/lib/libnarrate.py"):
             continue
-        if glob.fnmatch.fnmatch(potfile,"*.py"):
-            suite.addTest(TestGetText('test_gettext_py_%04d', potfile,
-                                      ["import gettext",
-                                       "from gramps.gen.ggettext",
-                                       "import sgettext"]))
-        elif glob.fnmatch.fnmatch(potfile,"*.glade"):
-            suite.addTest(TestGetText('test_gettext_glade_%04d', potfile,
-                                      ["translatable=\"yes\""]))
+        if glob.fnmatch.fnmatch(potfile, "*.py"):
+            suite.addTest(
+                TestGetText(
+                    "test_gettext_py_%04d",
+                    potfile,
+                    ["import gettext", "from gramps.gen.ggettext", "import sgettext"],
+                )
+            )
+        elif glob.fnmatch.fnmatch(potfile, "*.glade"):
+            suite.addTest(
+                TestGetText("test_gettext_glade_%04d", potfile, ['translatable="yes"'])
+            )
     return suite
 
+
 def suite3():
     """
     Looks for duplicates in POTFILES.in.
@@ -177,9 +207,10 @@ def suite3():
     suite = unittest.TestSuite()
     for potfile in set(get_potfile("../POTFILES.in")):
         if potfile:
-            suite.addTest(TestDups('test_dups_%04d', potfile))
+            suite.addTest(TestDups("test_dups_%04d", potfile))
     return suite
 
+
 if __name__ == "__main__":
     unittest.TextTestRunner().run(suite1())
     unittest.TextTestRunner().run(suite2())
